@@ -24,7 +24,7 @@ class WLANInterface(AbstractInterface):
       'statistics': {'name': self.wifi_icd2_statistics_signal, 'iface': self.wifi_icd2_iface, 'path': self.wifi_icd2_path, 'args': {}}
     },
     'images': ('ifsw_statusarea_wlan_off', 'ifsw_statusarea_wlan_on', 'ifsw_statusarea_wlan_online'),
-    'images_st': ('ifsw_statusarea_wlan_signal_0', 'ifsw_statusarea_wlan_signal_1', 'ifsw_statusarea_wlan_signal_1', 'ifsw_statusarea_wlan_signal_2', 'ifsw_statusarea_wlan_signal_2', 'ifsw_statusarea_wlan_signal_3', 'ifsw_statusarea_wlan_signal_3'),
+    'images_st': ('ifsw_statusarea_wlan_signal_0', 'ifsw_statusarea_wlan_signal_1', 'ifsw_statusarea_wlan_signal_1', 'ifsw_statusarea_wlan_signal_2', 'ifsw_statusarea_wlan_signal_3', 'ifsw_statusarea_wlan_signal_3'),
     'text': ('Off', 'On', '<>'),
     'show': (True, False, False),
     'banner': (True, True, True),
@@ -53,7 +53,7 @@ class WLANInterface(AbstractInterface):
     return None, None, None
 
   def process_signal_statistics(self, *args):
-    return None, None, int(args[7])
+    return None, None, min(int(args[7]), 5)
 
   def get_status(self):
     result = int(get_shell_command_output('lsmod | grep -o wl12xx') != '')
